Contains the ParsecData struct, which holds the PARSEC data for a given metallicity.
Structs
- Parsec
Data - The data struct holding the PARSEC data for a given metallicity. This struct cannot be created directly, but can only be read and accessed through the crate api. If you know the metallicity index, the contained trajectories can be accessed via the index operator.